@@ -12,7 +12,7 @@ except ModuleNotFoundError:
     import tomli as tomllib
 import numpy as np
 import pandas as pd
-from typing import Any, Union, TextIO
+from typing import Any, Union, TextIO, List, Tuple, Dict, Optional
 from .odb_visualizer import OdbVisualizer
 from .util import confirm
 from .state import CLIOptions, UserOptions, process_input, print_state, load_views_dict
@@ -26,7 +26,7 @@ def cli() -> None:
     # TODO Process input toml file and/or cli switches here
     state: OdbVisualizer
     user_options: UserOptions
-    result: Union[tuple[OdbVisualizer, UserOptions], pd.DataFrame]
+    result: Union[Tuple[OdbVisualizer, UserOptions], pd.DataFrame]
     result = process_input()
     print(f"ODBPlotter {__version__}")
     if isinstance(result, pd.DataFrame):
@@ -56,9 +56,6 @@ def cli() -> None:
             elif user_input in cli_options.convert_options:
                 convert(state)
 
-            elif user_input in cli_options.seed_options:
-                set_seed_size(state)
-
             elif user_input in cli_options.extrema_options:
                 set_extrema(state)
 
@@ -118,8 +115,8 @@ def cli() -> None:
 
 
 def select_files(state: OdbVisualizer, user_options: UserOptions) -> None:
-    odb_options: tuple[str, str] = ("odb", ".odb")
-    hdf_options: tuple[str, str, str, str, str ,str] = (".hdf", "hdf", ".hdf5", "hdf5", "hdfs", ".hdfs")
+    odb_options: Tuple[str, str] = ("odb", ".odb")
+    hdf_options: Tuple[str, str, str, str, str ,str] = (".hdf", "hdf", ".hdf5", "hdf5", "hdfs", ".hdfs")
     user_input: str
 
     # select odb
@@ -139,7 +136,7 @@ def select_files(state: OdbVisualizer, user_options: UserOptions) -> None:
         while not odb_path_valid:
             user_input = input("Please enter the path of the odb file: ")
             if(confirm(f"You entered {user_input}", "Is this correct", "yes")):
-                output: Union[bool, None] = state.select_odb(user_options, user_input)
+                output: Optional[bool] = state.select_odb(user_options, user_input)
                 if isinstance(output, bool):
                     print(f"Error: the file {user_input} could not be found")
 
@@ -186,23 +183,19 @@ def convert(state: OdbVisualizer) -> None:
 
 
 def pre_process_data(state: OdbVisualizer, user_options: UserOptions):
-    mesh_seed_size: Union[float, None] = None
-    meltpoint: Union[float, None] = None
-    low_temp: Union[float, None] = None
-    time_sample: Union[int, None] = None
+    meltpoint: Optional[float] = None
+    low_temp: Optional[float] = None
+    time_sample: Optional[int] = None
 
     if user_options.config_file_path is not None:
         config_file: TextIO
         with open(user_options.config_file_path, "rb") as config_file:
-            config: dict[str, Any] = tomllib.load(config_file)
+            config: Dict[str, Any] = tomllib.load(config_file)
 
         if "hdf_file_path" in config:
             if config["hdf_file_path"] != state.hdf_file_path:
                 print("INFO: File name provided and File Name in the config do not match. This could be an issue, or it might be fine")
 
-        if "mesh_seed_size" in config:
-            mesh_seed_size = config["mesh_seed_size"]
-
         if "meltpoint" in config:
             meltpoint = config["meltpoint"]
 
@@ -212,18 +205,6 @@ def pre_process_data(state: OdbVisualizer, user_options: UserOptions):
         if "time_sample" in config:
             time_sample = config["time_sample"]
 
-        # Manage mesh_seed_size
-        if mesh_seed_size is not None:
-            print(f"Setting Mesh Seed Size to stored value of {mesh_seed_size}")
-            state.set_mesh_seed_size(mesh_seed_size)
-
-        elif hasattr(state, "mesh_seed_size"):
-            print(f"Setting Default Seed Size of the Mesh to given value of {state.mesh_seed_size}")
-
-        else: # Neither the stored value or the given value exist
-            print("No Mesh Seed Size found. You must set it:")
-            set_seed_size(state)
-
         # Manage meltpoint
         if meltpoint is not None:
             print(f"Setting Melting Point to stored value of {meltpoint}")
@@ -260,11 +241,7 @@ def pre_process_data(state: OdbVisualizer, user_options: UserOptions):
             print("No Time Sample found. You must set it:")
             set_time_sample(state)
 
-    if not all((hasattr(state, "mesh_seed_size"), hasattr(state, "meltpoint"), hasattr(state, "low_temp"), hasattr(state, "time_sample"))):
-
-        # here, we need to set at least one of the things
-        if mesh_seed_size is None:
-            set_seed_size(state)
+    if not all(hasattr(state, "meltpoint"), hasattr(state, "low_temp"), hasattr(state, "time_sample")):
 
         if meltpoint is None:
             set_meltpoint(state)
@@ -281,7 +258,7 @@ def pre_process_data(state: OdbVisualizer, user_options: UserOptions):
     state.select_colormap()
 
 
-def set_title_and_label(state: OdbVisualizer, user_options: UserOptions):
+def set_title_and_label(state: OdbVisualizer, user_options: UserOptions) -> None:
     default_title: str = ""
 
     if hasattr(state, "hdf_file_path"):
@@ -321,7 +298,7 @@ def set_title_and_label(state: OdbVisualizer, user_options: UserOptions):
             break
 
 
-def set_directories(user_options: UserOptions):
+def set_directories(user_options: UserOptions) -> None:
     print(f"For setting all of these data directories, Please enter either absolute paths, or paths relative to your present working directory: {os.getcwd()}")
     user_input: str
 
@@ -386,7 +363,7 @@ def set_directories(user_options: UserOptions):
                 print(f"Error: That directory does not exist. Please enter the absolute path to a directory or the path relative to your present working directory: {os.getcwd()}")
 
 
-def set_extrema(state: OdbVisualizer):
+def set_extrema(state: OdbVisualizer) -> None:
     x_low: float
     x_high: float
     y_low: float
@@ -395,12 +372,12 @@ def set_extrema(state: OdbVisualizer):
     z_high: float
     while True:
         # Get the desired coordinates and time steps to plot
-        extrema: dict[tuple[str, str], tuple[float, float]] = {
+        extrema: Dict[Tuple[str, str], Tuple[float, float]] = {
                 ("lower X", "upper X"): tuple(),
                 ("lower Y", "upper Y"): tuple(),
                 ("lower Z", "upper Z"): tuple(),
                 }
-        extremum: tuple[str, str]
+        extremum: Tuple[str, str]
         for extremum in extrema.keys():
             extrema[extremum] = process_extrema(extremum)
 
@@ -419,21 +396,6 @@ def set_extrema(state: OdbVisualizer):
             break
 
 
-def set_seed_size(state: OdbVisualizer) -> None:
-    print("INFO: You must enter the Mesh Seed Size with which the .hdf5 was generated")
-    while True:
-        try:
-            seed: float = float(input("Enter the Default Seed Size of the Mesh: "))
-
-            if confirm(f"Mesh Seed Size: {seed}", "Is this correct", "yes"):
-                state.set_mesh_seed_size(seed)
-                print(f"Mesh Seed Size set to: {state.mesh_seed_size}")
-                break
-
-        except ValueError:
-            print("Error, Default Seed Size must be a number")
-
-
 def set_meltpoint(state: OdbVisualizer) -> None:
     while True:
         try:
@@ -479,9 +441,9 @@ def set_time(state: OdbVisualizer) -> None:
     lower_time: Union[int, float] = 0
     upper_time: Union[int, float] = float("inf")
     while True:
-        values: list[tuple[str, Union[int, float], str]] = [("lower time", 0, "0"), ("upper time", float("inf"), "infinity")]
+        values: List[Tuple[str, Union[int, float], str]] = [("lower time", 0, "0"), ("upper time", float("inf"), "infinity")]
         i: int
-        v: tuple[str, Union[int, float], str]
+        v: Tuple[str, Union[int, float], str]
         for i, v in enumerate(values): 
             key: str
             default: Union[int, float]
@@ -512,8 +474,8 @@ def set_time(state: OdbVisualizer) -> None:
             break
 
 
-def process_extrema(keys: "tuple[str, str]") -> "tuple[float, float]":
-    results: list[float] = list()
+def process_extrema(keys: "Tuple[str, str]") -> "Tuple[float, float]":
+    results: List[float] = list()
     i: int
     key: str
     inf_addon: str
@@ -540,13 +502,13 @@ def process_extrema(keys: "tuple[str, str]") -> "tuple[float, float]":
     return tuple(results)
 
 
-def load_hdf(state: OdbVisualizer):
+def load_hdf(state: OdbVisualizer) -> None:
     state.process_hdf()
 
 
 # TODO Fix
-def set_views(state: OdbVisualizer):
-    views_dict: dict[str, dict[str, int]] = load_views_dict()
+def set_views(state: OdbVisualizer) -> None:
+    views_dict: Dict[str, Dict[str, int]] = load_views_dict()
     while True:
         print("Please Select a Preset View for your plots")
         print('To view all default presets, please enter "list"')
@@ -584,7 +546,7 @@ def set_views(state: OdbVisualizer):
                 print('Error: input must be "list," "custom," or the index or name of a named view as seen from the "list" command.')
 
 
-def get_custom_view() -> "tuple[int, int, int]":
+def get_custom_view() -> "Tuple[int, int, int]":
     elev: int
     azim: int
     roll: int
@@ -614,11 +576,11 @@ def get_custom_view() -> "tuple[int, int, int]":
     return (elev, azim, roll)
 
 
-def print_views(views: "dict[str, dict[str, int]]") -> None:
+def print_views(views: "Dict[str, Dict[str, int]]") -> None:
     print("Index | Name | Rotation Values")
-    v: tuple[str, dict[str, int]]
+    v: Tuple[str, Dict[str, int]]
     view: str
-    vals: dict[str, int]
+    vals: Dict[str, int]
     key: str
     val: int
     for i, v in enumerate(views.items()):
@@ -688,4 +650,4 @@ def plot_time_slice(time: float, state: OdbVisualizer, user_options: UserOptions
         # with plot.window_size_context((1920, 1080)):
         #     plot.screenshot(save_str)
 
-    del plot
\ No newline at end of file
+    del plot
