@@ -10,7 +10,7 @@ import platformdirs
 import subprocess
 import pickle
 import pandas as pd
-from typing import Union, Any, TextIO
+from typing import Union, Any, TextIO, Tuple, List, Dict, Optional
 from .odb_visualizer import OdbVisualizer
 from .util import confirm
 from odbp import __version__
@@ -35,7 +35,7 @@ class UserOptions():
         self.results_directory: str = ""
         self.image_title: str = ""
         self.image_label: str = ""
-        self.config_file_path: Union[str, None] = None
+        self.config_file_path: Optional[str] = None
         self.run_immediate: bool = False
 
 
@@ -44,79 +44,75 @@ class CLIOptions():
     Struct to store cli options without repeating
     """
     def __init__(self) -> None:
-        self.quit_options: list[str] = ["exit", "quit", "q"]
+        self.quit_options: List[str] = ["exit", "quit", "q"]
         self.quit_help: str = "Exit ODBPlotter"
         self.quit_options_formatted: str = ", ".join(self.quit_options)
 
-        self.select_options: list[str] = ["select"]
+        self.select_options: List[str] = ["select"]
         self.select_help: str = "Select a .hdf5 file or a .odb file"
         self.select_options_formatted: str = ", ".join(self.select_options)
 
-        self.convert_options: list[str] = ["convert"]
+        self.convert_options: List[str] = ["convert"]
         self.convert_help: str = "Convert a selected .odb file to a .hdf5 file"
         self.convert_options_formatted: str = ", ".join(self.convert_options)
 
-        self.seed_options: list[str] = ["seed", "mesh"]
-        self.seed_help: str = "Set the Mesh Seed Size"
-        self.seed_options_formatted: str = ", ".join(self.seed_options)
-
-        self.extrema_options: list[str] = ["extrema", "range"]
+        self.extrema_options: List[str] = ["extrema", "range"]
         self.extrema_help: str = "Set the upper and lower x, y, and z bounds for plotting"
         self.extrema_options_formatted: str = ", ".join(self.extrema_options)
 
-        self.time_options: list[str] = ["time"]
+        self.time_options: List[str] = ["time"]
         self.time_help: str = "Set the upper and lower time bounds"
         self.time_options_formatted: str = ", ".join(self.time_options)
 
-        self.time_sample_options: list[str] = ["sample"]
+        self.time_sample_options: List[str] = ["sample"]
         self.time_sample_help: str = "Set the Time Sample for the hdf5 file"
         self.time_sample_options_formatted: str = ", ".join(self.time_sample_options)
 
-        self.meltpoint_options: list[str] = ["meltpoint", "melt", "point"]
+        self.meltpoint_options: List[str] = ["meltpoint", "melt", "point"]
         self.meltpoint_help: str = "Set the Melting Point for the hdf5 file"
         self.meltpoint_options_formatted: str = ", ".join(self.meltpoint_options)
 
-        self.low_temp_options: list[str] = ["low", "low-temp"]
+        self.low_temp_options: List[str] = ["low", "low-temp"]
         self.low_temp_help: str = "Set the Lower Temperate Bound for the hdf5 file"
         self.low_temp_options_formatted: str = ", ".join(self.low_temp_options)
 
-        self.title_label_options: list[str] = ["title", "label"]
+        self.title_label_options: List[str] = ["title", "label"]
         self.title_label_help: str = "Set the title and label of the output plots"
         self.title_label_options_formatted: str = ", ".join(self.title_label_options)
 
-        self.directory_options: list[str] = ["dir", "dirs", "directory", "directories"]
+        self.directory_options: List[str] = ["dir", "dirs", "directory", "directories"]
         self.directory_help: str = "Set the source and output directories"
         self.directory_options_formatted: str = ", ".join(self.directory_options)
 
-        self.process_options: list[str] = ["process", "run", "load"]
+        self.process_options: List[str] = ["process", "run", "load"]
         self.process_help: str = "Actually load the selected data from the file set in select"
         self.process_options_formatted: str = ", ".join(self.process_options)
 
-        self.angle_options: list[str] = ["angle",]
+        self.angle_options: List[str] = ["angle",]
         self.angle_help: str = "Update the viewing angle"
         self.angle_options_formatted: str = ", ".join(self.angle_options)
 
-        self.show_all_options: list[str] = ["show-all", "plot-all"]
+        self.show_all_options: List[str] = ["show-all", "plot-all"]
         self.show_all_help: str = "Toggle if each time step will be shown in the PyVista interactive viewer"
         self.show_all_options_formatted: str = ", ".join(self.show_all_options)
 
-        self.plot_options: list[str] = ["plot", "show"]
+        self.plot_options: List[str] = ["plot", "show"]
         self.plot_help: str = "Plot each selected timestep"
         self.plot_options_formatted: str = ", ".join(self.plot_options)
         
-        self.state_options: list[str] = ["state", "status", "settings"]
+        self.state_options: List[str] = ["state", "status", "settings"]
         self.state_help: str = "Show the current state of the settings of the plotter"
         self.state_options_formatted: str = ", ".join(self.state_options)
 
-        self.abaqus_options: list[str] = ["abaqus", "abq", "abqpy"]
+        self.abaqus_options: List[str] = ["abaqus", "abq", "abqpy"]
         self.abaqus_help: str = "Select the Abaqus executable program to use to process .odb file"
         self.abaqus_options_formatted: str = ", ".join(self.abaqus_options)
 
-        self.nodeset_options: list[str] = ["node", "nodes", "nodeset", "nodesets"]
+        self.nodeset_options: List[str] = ["node", "nodes", "nodeset", "nodesets"]
         self.nodeset_help: str = "Select the target nodeset (i.e., the named nodeset that contains all the data)"
         self.nodeset_options_formatted: str = ", ".join(self.nodeset_options)
 
-        self.help_options: list[str] = ["help", "use", "usage"]
+        self.help_options: List[str] = ["help", "use", "usage"]
         self.help_help: str = "Show this menu"
         self.help_options_formatted: str = ", ".join(self.help_options)
 
@@ -124,7 +120,6 @@ class CLIOptions():
                 len(self.quit_options_formatted),
                 len(self.select_options_formatted),
                 len(self.convert_options_formatted),
-                len(self.seed_options_formatted),
                 len(self.extrema_options_formatted),
                 len(self.time_options_formatted),
                 len(self.time_sample_options_formatted),
@@ -146,7 +141,6 @@ class CLIOptions():
 {self.quit_options_formatted.ljust(self.longest_len) } -- {self.quit_help}
 {self.select_options_formatted.ljust(self.longest_len)} -- {self.select_help}
 {self.convert_options_formatted.ljust(self.longest_len)} -- {self.convert_help}
-{self.seed_options_formatted.ljust(self.longest_len)} -- {self.seed_help}
 {self.extrema_options_formatted.ljust(self.longest_len)} -- {self.extrema_help}
 {self.time_options_formatted.ljust(self.longest_len)} -- {self.time_help}
 {self.time_sample_options_formatted.ljust(self.longest_len)} -- {self.time_sample_help}
@@ -165,7 +159,7 @@ class CLIOptions():
 
 
 def print_state(state: OdbVisualizer, user_options: UserOptions) -> None:
-    lines: list[dict[str, str]] = [
+    lines: List[Dict[str, str]] = [
         {
             ".hdf5 file": f"{state.hdf_file_path if hasattr(state, 'hdf_file_path') else 'not set'}",
             ".odb file": f"{state.odb_file_path if hasattr(state, 'odb_file_path') else 'not set'}",
@@ -183,7 +177,6 @@ def print_state(state: OdbVisualizer, user_options: UserOptions) -> None:
             "Temperature Range": f"{state.low_temp if hasattr(state, 'low_temp') else 'not set'} to {state.meltpoint if hasattr(state, 'meltpoint') else 'not set'}",
         },
         {
-            "Seed Size of the Mesh": f"{state.mesh_seed_size if hasattr(state, 'mesh_seed_size') else 'not set'}",
             "Time Sample of the Mesh": f"{state.time_sample if hasattr(state, 'time_sample') else 'not set'}",
         },
         {
@@ -209,7 +202,7 @@ def print_state(state: OdbVisualizer, user_options: UserOptions) -> None:
 
     key: str
     val: str
-    sub_dict: dict[str, str]
+    sub_dict: Dict[str, str]
     max_len = 0
     for sub_dict in lines:
         for key in sub_dict.keys():
@@ -224,7 +217,7 @@ def print_state(state: OdbVisualizer, user_options: UserOptions) -> None:
     print(final_state_output, end="") # No ending newline because we added it above
 
 
-def process_input() -> "Union[tuple[OdbVisualizer, UserOptions], pd.DataFrame]": # Returns UserOptions or Pandas Dataframe
+def process_input() -> "Union[Tuple[OdbVisualizer, UserOptions], pd.DataFrame]": # Returns UserOptions or Pandas Dataframe
     """
     The goal is to have a hierarchy of options. If a user passes in an option via a command-line switch, that option is set.
     If an option is not set by a switch, then the toml input file is used.
@@ -247,7 +240,6 @@ def process_input() -> "Union[tuple[OdbVisualizer, UserOptions], pd.DataFrame]":
     parser.add_argument("-o", "--odb", help="Path to the desired .odb file")
     parser.add_argument("-m", "--meltpoint", help="Melting Point of the Mesh")
     parser.add_argument("-l", "--low-temp", help="Temperature lower bound, defaults to 300 K")
-    parser.add_argument("-S", "--mesh-seed-size", help="Mesh seed size of the .odb file")
     parser.add_argument("-t", "--time-sample", help="Time-sample value (N for every Nth frame you extracted). Defaults to 1")
 
     parser.add_argument("-H", "--hdf", help="Path to desired .hdf5 file")
@@ -289,7 +281,7 @@ def process_input() -> "Union[tuple[OdbVisualizer, UserOptions], pd.DataFrame]":
         return generate_cli_settings(args)
 
 
-def generate_cli_settings(args: argparse.Namespace) -> "tuple[OdbVisualizer, UserOptions]":
+def generate_cli_settings(args: argparse.Namespace) -> "Tuple[OdbVisualizer, UserOptions]":
 
     state: OdbVisualizer = OdbVisualizer()
     user_options: UserOptions = UserOptions()
@@ -311,7 +303,7 @@ def generate_cli_settings(args: argparse.Namespace) -> "tuple[OdbVisualizer, Use
             new_config_file.write(config_data)
 
     config_file: TextIO
-    config_settings: dict[str, Any]
+    config_settings: Dict[str, Any]
     with open(config_file_path, "rb") as config_file:
         config_settings = tomllib.load(config_file)
     state, user_options = read_setting_dict(state, user_options, config_settings)
@@ -327,14 +319,14 @@ def generate_cli_settings(args: argparse.Namespace) -> "tuple[OdbVisualizer, Use
                 input_file_path = os.path.join(os.getcwd(), input_file_path)
 
         input_file: TextIO
-        input_settings: dict[str, Any]
+        input_settings: Dict[str, Any]
         with open(input_file_path, "rb") as input_file:
             input_settings = tomllib.load(input_file)
 
         state, user_options = read_setting_dict(state, user_options, input_settings)
 
     # Stage 3: pass in the (other) dict values from args
-    cli_flags: dict[str, any] = vars(args)
+    cli_flags: Dict[str, any] = vars(args)
     cli_flags = {k: v for k, v in cli_flags.items() if v is not None}
     state, user_options = read_setting_dict(state, user_options, cli_flags)
 
@@ -354,58 +346,10 @@ def generate_cli_settings(args: argparse.Namespace) -> "tuple[OdbVisualizer, Use
 
 
 def extract_from_file(args: argparse.Namespace) -> pd.DataFrame:
-    if not args.odb:
-        print("Error: You must supply the path to a .odb file from which to extract")
-        sys.exit(1)
-
-    state: OdbVisualizer
-    state, _ = generate_cli_settings(args)
-
-    odb_extract_script_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "py2_scripts", "extract.py")
-    temp_save_path = os.path.join(os.getcwd(), "temp.pickle")
-
-    # Because of the python3-2 cross-talk, we use strings of "None", unfortunately
-    parts: Union[list[str], None] = None
-    nodesets: Union[list[str], None] = None
-    nodes: Union[dict[str, list[int]], None] = None
-    if hasattr(state, "parts"):
-        parts = state.parts
-
-    if hasattr(state, "nodesets"):
-        nodesets = state.nodesets
-
-    if hasattr(state, "nodes"):
-        nodes = state.nodes
-
-    # subprocess won't handle the Nones or dicts or lists well, so instead we pickle in the output path, and read in the python2 version
-    # They're all built-ins, so pickle should work
-    temp_file: TextIO
-    input_dict: dict[str, Any] = {
-        "parts": parts,
-        "nodesets": nodesets,
-        "nodes": nodes,
-    }
-    # TODO Time Sample
-    with open(temp_save_path, "wb") as temp_file:
-        pickle.dump(input_dict, temp_file, protocol=2)
-    odb_extract_args: list[str] = [state.abaqus_program, "python", odb_extract_script_path, state.odb_file_path, temp_save_path]
-    subprocess.run(odb_extract_args, shell=True)
-
-    #odb_to_npz_args: list[str] = [self.abaqus_program, "python", odb_to_npz_script_path, os.path.join(os.getcwd(), self.odb_file_path), str(self.time_sample)]
-    #subprocess.run(odb_to_npz_args, shell=True)
-
-    return_data: pd.DataFrame
-    with open(temp_save_path, "rb") as temp_file:
-        # From the Pickle Spec, decoding numpy arrays from python 2 must use encoding="latin-1"
-        return_data = pd.DataFrame(pickle.load(temp_file, encoding="latin-1"))
-
-    if os.path.exists(temp_save_path):
-        os.remove(temp_save_path)
-
-    return return_data
+    pass
 
 
-def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_dict: "dict[str, Any]") -> "tuple[OdbVisualizer, UserOptions]":
+def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_dict: "Dict[str, Any]") -> "Tuple[OdbVisualizer, UserOptions]":
     hdf_source_dir: str
     if "hdf_source_directory" in settings_dict:
         hdf_source_dir = os.path.abspath(settings_dict["hdf_source_directory"])
@@ -464,9 +408,6 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
         if "low_temp" in settings_dict:
             state.set_low_temp(settings_dict["low_temp"])
 
-        if "mesh_seed_size" in settings_dict:
-            state.set_mesh_seed_size(settings_dict["mesh_seed_size"])
-
         if "time_sample" in settings_dict:
             state.set_time_sample(settings_dict["time_sample"])
 
@@ -486,10 +427,9 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
 
         # If none of these values are set, read as many as are available out of the .toml config file
         # Otherwise, the file must have already been read
-        # if not hasattr(state, "meltpoint") and not hasattr(state, "low_temp") and not hasattr(state, "mesh_seed_size") and not hasattr(state, "time_sample"):
 
         # Search for the stored toml values for this hdf
-        config: Union[dict[str, Any], None] = None
+        config: Optional[Dict[str, Any]] = None
         if user_options.config_file_path is None:
             print(f".toml config file for {state.hdf_file_path} could not be found")
         else:
@@ -507,11 +447,6 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
         elif "low_temp" in settings_dict:
             state.set_low_temp(settings_dict["low_temp"])
 
-        if config is not None and "mesh_seed_size" in config:
-            state.set_mesh_seed_size(config["mesh_seed_size"])
-        elif "mesh_seed_size" in settings_dict:
-            state.set_mesh_seed_size(settings_dict["mesh_seed_size"])
-
         if config is not None and "time_sample" in config:
             state.set_time_sample(config["time_sample"])
         elif "time_sample" in settings_dict:
@@ -525,9 +460,6 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
         if "low_temp" in settings_dict:
             state.set_low_temp(settings_dict["low_temp"])
 
-        if "mesh_seed_size" in settings_dict:
-            state.set_mesh_seed_size(settings_dict["mesh_seed_size"])
-
         if "time_sample" in settings_dict:
             state.set_time_sample(settings_dict["time_sample"])
 
@@ -608,7 +540,7 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
             state.roll = settings_dict["view"]["roll"]
         
         else:
-            given_view: dict[str, int] = view(settings_dict["view"])
+            given_view: Dict[str, int] = view(settings_dict["view"])
             elev: int = given_view["elev"]
             azim: int = given_view["azim"]
             roll: int = given_view["roll"]
@@ -646,15 +578,15 @@ def read_setting_dict(state: OdbVisualizer, user_options: UserOptions, settings_
     return (state, user_options)
 
 
-def load_views_dict() -> "dict[str, dict[str, int]]":
+def load_views_dict() -> "Dict[str, Dict[str, int]]":
     views_file: TextIO
     with open(os.path.join(os.path.dirname(os.path.realpath(__file__)), "data", "views.toml"), "rb") as views_file:
         return tomllib.load(views_file)
 
 
 # Used to define the "view" type for argparse
-def view(string: str) -> "dict[str, int]":
-    views_dict: dict[str, dict[str, int]] = load_views_dict()
+def view(string: str) -> "Dict[str, int]":
+    views_dict: Dict[str, Dict[str, int]] = load_views_dict()
     if string in views_dict:
         return views_dict[string]
 
